Method: Omnibus::NetFetcher#version_for_cache
- Defined in:
- lib/omnibus/fetchers/net_fetcher.rb
#version_for_cache ⇒ String
The version for this item in the cache. This is the digest of downloaded file and the URL where it was downloaded from.
This method is called before clean but after fetch. Do not ever use the contents of the project_dir here.
99 100 101 |
# File 'lib/omnibus/fetchers/net_fetcher.rb', line 99 def version_for_cache "download_url:#{source[:url]}|#{digest_type}:#{checksum}" end |