Method: Omnibus::Project#package_name
- Defined in:
- lib/omnibus/project.rb
#package_name(val = NULL) ⇒ String
Set or retrieve the package name of the project. Defaults to the package name defaults to the project name.
148 149 150 151 152 153 154 |
# File 'lib/omnibus/project.rb', line 148 def package_name(val = NULL) if null?(val) @package_name || name else @package_name = val end end |